==> haskell-ghc-lib-parser-ex-9.6.0.2-3.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-ghc-lib-parser-ex.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghc-lib-parser-ex
version:              9.6.0.2
visibility:           public
id:                   ghc-lib-parser-ex-9.6.0.2-8X52mS6lbEo3Fw3qe9swLM
key:                  ghc-lib-parser-ex-9.6.0.2-8X52mS6lbEo3Fw3qe9swLM
license:              BSD-3-Clause
copyright:            Copyright © 2020-2022 Shayne Fletcher. All rights reserved.
maintainer:           shayne@shaynefletcher.org
author:               Shayne Fletcher
homepage:             https://github.com/shayne-fletcher/ghc-lib-parser-ex#readme
synopsis:             Algorithms on GHC parse trees
description:
    Please see the README on GitHub at <https://github.com/shayne-fletcher/ghc-lib-parser-ex#readme>

category:             Development
abi:                  b3e912e00c0da63dafb1f8d4aa9ca7f3
exposed:              True
exposed-modules:
    Language.Haskell.GhclibParserEx.Dump
    Language.Haskell.GhclibParserEx.Fixity
    Language.Haskell.GhclibParserEx.GHC.Driver.Flags
    Language.Haskell.GhclibParserEx.GHC.Driver.Session
    Language.Haskell.GhclibParserEx.GHC.Hs
    Language.Haskell.GhclibParserEx.GHC.Hs.Binds
    Language.Haskell.GhclibParserEx.GHC.Hs.Decls
    Language.Haskell.GhclibParserEx.GHC.Hs.Expr
    Language.Haskell.GhclibParserEx.GHC.Hs.ExtendInstances
    Language.Haskell.GhclibParserEx.GHC.Hs.ImpExp
    Language.Haskell.GhclibParserEx.GHC.Hs.Pat
    Language.Haskell.GhclibParserEx.GHC.Hs.Type
    Language.Haskell.GhclibParserEx.GHC.Hs.Types
    Language.Haskell.GhclibParserEx.GHC.Parser
    Language.Haskell.GhclibParserEx.GHC.Settings.Config
    Language.Haskell.GhclibParserEx.GHC.Types.Name.Reader
    Language.Haskell.GhclibParserEx.GHC.Utils.Outputable

hidden-modules:       Paths_ghc_lib_parser_ex
import-dirs:          /usr/lib/ghc-9.6.6/site-local/ghc-lib-parser-ex-9.6.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ghc-lib-parser-ex-9.6.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ghc-lib-parser-ex-9.6.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghc-lib-parser-ex
hs-libraries:         HSghc-lib-parser-ex-9.6.0.2-8X52mS6lbEo3Fw3qe9swLM
include-dirs:
    /usr/lib/ghc-9.6.6/site-local/ghc-lib-parser-ex-9.6.0.2/include

depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7 ghc-9.6.6
    ghc-boot-9.6.6 ghc-boot-th-9.6.6
    uniplate-1.6.13-3WatGBC3kLsu5Mf9WJ1JN

haddock-interfaces:
    /usr/share/doc/haskell-ghc-lib-parser-ex/html/ghc-lib-parser-ex.haddock

haddock-html:         /usr/share/doc/haskell-ghc-lib-parser-ex/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ghc-lib-parser-ex-9.6.0.2-4-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-ghc-lib-parser-ex.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghc-lib-parser-ex
version:              9.6.0.2
visibility:           public
id:                   ghc-lib-parser-ex-9.6.0.2-N3OL9MDf2AGszziPvbcmG
key:                  ghc-lib-parser-ex-9.6.0.2-N3OL9MDf2AGszziPvbcmG
license:              BSD-3-Clause
copyright:            Copyright © 2020-2022 Shayne Fletcher. All rights reserved.
maintainer:           shayne@shaynefletcher.org
author:               Shayne Fletcher
homepage:             https://github.com/shayne-fletcher/ghc-lib-parser-ex#readme
synopsis:             Algorithms on GHC parse trees
description:
    Please see the README on GitHub at <https://github.com/shayne-fletcher/ghc-lib-parser-ex#readme>

category:             Development
abi:                  9df5388e3a7c4d01698a799d282299d7
exposed:              True
exposed-modules:
    Language.Haskell.GhclibParserEx.Dump
    Language.Haskell.GhclibParserEx.Fixity
    Language.Haskell.GhclibParserEx.GHC.Driver.Flags
    Language.Haskell.GhclibParserEx.GHC.Driver.Session
    Language.Haskell.GhclibParserEx.GHC.Hs
    Language.Haskell.GhclibParserEx.GHC.Hs.Binds
    Language.Haskell.GhclibParserEx.GHC.Hs.Decls
    Language.Haskell.GhclibParserEx.GHC.Hs.Expr
    Language.Haskell.GhclibParserEx.GHC.Hs.ExtendInstances
    Language.Haskell.GhclibParserEx.GHC.Hs.ImpExp
    Language.Haskell.GhclibParserEx.GHC.Hs.Pat
    Language.Haskell.GhclibParserEx.GHC.Hs.Type
    Language.Haskell.GhclibParserEx.GHC.Hs.Types
    Language.Haskell.GhclibParserEx.GHC.Parser
    Language.Haskell.GhclibParserEx.GHC.Settings.Config
    Language.Haskell.GhclibParserEx.GHC.Types.Name.Reader
    Language.Haskell.GhclibParserEx.GHC.Utils.Outputable

hidden-modules:       Paths_ghc_lib_parser_ex
import-dirs:          /usr/lib/ghc-9.6.6/site-local/ghc-lib-parser-ex-9.6.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ghc-lib-parser-ex-9.6.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ghc-lib-parser-ex-9.6.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghc-lib-parser-ex
hs-libraries:         HSghc-lib-parser-ex-9.6.0.2-N3OL9MDf2AGszziPvbcmG
include-dirs:
    /usr/lib/ghc-9.6.6/site-local/ghc-lib-parser-ex-9.6.0.2/include

depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7 ghc-9.6.6
    ghc-boot-9.6.6 ghc-boot-th-9.6.6
    uniplate-1.6.13-KGH5CSn0bIt6TRjVfDPPFU

haddock-interfaces:
    /usr/share/doc/haskell-ghc-lib-parser-ex/html/ghc-lib-parser-ex.haddock

haddock-html:         /usr/share/doc/haskell-ghc-lib-parser-ex/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
